#
# spec file for package mtpaint
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2013 B1 Systems GmbH, Vohburg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mtpaint
Version:        3.40
Release:        14.2
Summary:        Painting program for creating icons and pixel-based artwork
License:        GPL-3.0+
Group:          Productivity/Graphics/Bitmap Editors
Url:            http://mtpaint.sourceforge.net/
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.bz2
Source1:        http://downloads.sourceforge.net/%{name}/%{name}_handbook-%{version}.zip
Patch0:         mtpaint-3.40-buff.diff
# PATCH-FIX-OPENSUSE mtpaint-3.40-xdg-open.patch -- fix hardcoded apps, options and handbook location
Patch1:         mtpaint-3.40-xdg-open.patch
# PATCH-FIX-OPENSUSE mtpaint-3.40-strip.patch rh#787462 -- don't strip binary
Patch2:         mtpaint-3.40-strip.patch
# PATCH-FIX-OPENSUSE mtpaint-3.40-giflib5.diff -- fix build with giflib-5.x
Patch3:         mtpaint-3.40-giflib5.diff
BuildRequires:  giflib-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  unzip
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} >= 1220
BuildRequires:  desktop-file-utils
BuildRequires:  pkgconfig(libopenjpeg)
%else
BuildRequires:  libjasper-devel
BuildRequires:  update-desktop-files
%endif
Requires:       ImageMagick
Recommends:     %{name}-lang
Recommends:     exif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%lang_package

%description
mtPaint is a simple painting program designed for creating icons and
pixel-based artwork. It can edit indexed palette or 24 bit RGB images
and offers basic painting and palette manipulation tools. Its main
file format is PNG, although it can also handle JPEG, GIF, TIFF, BMP,
XPM, and XBM files.

%package handbook
Summary:        Handbook for the mtpaint painting application
License:        GFDL-1.2
Group:          Productivity/Graphics/Bitmap Editors
Requires:       %{name} = %{version}
BuildArch:      noarch

%description handbook
Install this package is want to read the handbook for the painting
application mtpaint.

%prep
%setup -q -a 1
%patch0 -p1
%patch1 -p1
%patch2
%patch3 -p1

%build
# fix warnings for gcc >= 4.4, use -fno-strict-aliasing
export CFLAGS="%{optflags} -fno-strict-aliasing"
# This is not a "normal" configure
./configure \
    --prefix=%{_prefix} \
    --docdir=%{_defaultdocdir}/%{name} \
    asneeded \
    cflags \
    GIF \
    gtk2 \
    gtkfilesel \
    imagick \
    intl \
%if 0%{?suse_version} >= 1220
    jp2 \
%else
    jasper \
%endif
    jpeg \
    lcms2 \
    man \
    tiff \
    thread
make %{?_smp_mflags}

%install
make install \
    MT_PREFIX=%{buildroot}%{_prefix} \
    BIN_INSTALL=%{buildroot}%{_bindir} \
    MT_DATAROOT=%{buildroot}%{_datadir} \
    MT_LANG_DEST=%{buildroot}%{_datadir}/locale \
    MT_MAN_DEST=%{buildroot}%{_mandir}

%find_lang %{name}

%post
%desktop_database_post

%postun
%desktop_database_postun

%files
%defattr(-, root, root, -)
%doc COPYING NEWS README
%{_bindir}/%{name}
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/%{name}.png
%doc %{_mandir}/man1/%{name}*

%files handbook
%defattr(-, root, root, -)
%doc %{name}_handbook-%{version}/COPYING %{name}_handbook-%{version}/docs/*

%files lang -f %{name}.lang

%changelog
* Tue Aug 19 2014 jengelh@inai.de
- Augment mtpaint-3.40-giflib5.diff to support giflib7 API
* Tue Mar 12 2013 seife+obs@b1-systems.com
- fix build with giflib-5.x (mtpaint-3.40-giflib5.diff)
* Mon Nov 19 2012 lazy.kent@opensuse.org
- Update to 3.40.
  * Usage of multiple CPU cores to speed up slower processing
    tasks.
  * Two new tools - for image segmentation, and for approximating
    gradients using palette colours.
  * Dynamic preview in colour selectors.
  * sRGB (linear RGB) colour scales and gradients.
  * Palette sorting by brightness.
  * Dock area to hold settings toolbar and layers window.
  * Colour chooser popup.
  * Autoscrolling in canvas, view and palette windows.
  * Auto-resizing toolbars.
  * Support for PBM/PGM/PPM/PAM, PCX and SVG image formats.
  * Support for ICC colour profiles in images.
  * Loading of animated GIFs and multipage TIFFs into layers.
  * Palette extraction from image files.
  * Format conversions in file actions.
  * "Snap to grid" mode.
  * New keyboard shortcuts.
  * And various speedups, interface improvements and bugfixes.
- Drop mtpaint-3.31-libpng14.patch,
  mtpaint-fix-no-add-needed.patch, mtpaint-3.31-openjpeg.patch,
  mtpaint-3.31-ld_fix.patch (fixed upstream or no need).
- Refresh mtpaint-buff.diff.
- Rework mtpaint-xdg-open.patch: fix hardcoded apps and options.
- Add mtpaint-3.40-strip.patch: don't strip binary (rh#787462).
- Correct build dependencies:
  * Remove: dos2unix, gettext.
  * Add: pkgconfig(libopenjpeg) (for openSUSE >= 12.2) or
    libjasper-devel, unzip, pkgconfig(lcms2).
  * Use pkgconfig(*).
- Requires ImageMagick; recommends exif.
- Don't call %%suse_update_desktop_file macro.
- Split off language subpackage.
- Correct configure options:
  * Remove: debug.
  * Add: gif, gtkfilesel, imagick, jp2 or jasper, lcms2, thread.
- Use parallel build.
- Remove check for unsupported openSUSE versions.
- Mark man as doc.
- Clean up and formatting spec.
* Mon Feb 27 2012 cfarrell@suse.com
- license update: GPL-3.0+
  For the docs look at the COPYING (1.2 _not_ 1.3). For the main package
  there is no indication that GPLv3 only is intended
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Sun Sep 18 2011 andrea@opensuse.org
- added mtpaint-3.31-ld_fix.patch to fix failure caused by new ld
* Sun Sep  4 2011 crrodriguez@opensuse.org
- Fix build with no-add-needed.
* Mon Mar 14 2011 gber@opensuse.org
- removed obsolete existing %%post/%%postun
* Mon Mar 14 2011 gber@opensuse.org
- call %%desktop_database_post/un
* Sun Apr  4 2010 andrea@opensuse.org
- added mtpaint-3.31-libpng14.patch on suse 11.3 to make it build
  with libpng14
* Sun Mar 21 2010 ro@suse.de
- use noarch only for >= 11.2
* Sat Feb 27 2010 andrea@opensuse.org
- new package (porting from packman)
